import { Octokit } from '@octokit/rest';
type Repo = {
    owner: string;
    repo: string;
};
type Release = {
    name: string;
    tag: string;
    notes: string;
};
type Asset = {
    name?: string;
    path: string;
    contentType?: string;
};
type Tag = {
    name: string;
    sha: string;
};
type ReleaseAsset = {
    id: number;
    name: string;
    url: string;
};
type ReleaseDetails = {
    draft: boolean;
    upload_url: string;
    id: number;
    assets?: ReleaseAsset[];
    html_url: string;
    tag_name: string;
};
type Branch = {
    ref: string;
    url: string;
    object: {
        sha: string;
        type: string;
        url: string;
    };
};
export declare class GithubRepo {
    private octokit;
    readonly repo: Readonly<Repo>;
    constructor(repo: Repo, octokit: Octokit);
    /**
     * Returns the most recent draft tag for the given release version (without leading `v`).
     */
    getMostRecentDraftTagForRelease(releaseVersion: string | undefined): Promise<Tag | undefined>;
    /**
     * Returns the predecessor release tag of the given release (without leading `v`).
     * @param releaseVersion The successor release
     */
    getPreviousReleaseTag(releaseVersion: string | undefined): Promise<Tag | undefined>;
    /**
     * Get all tags from the Github repository, sorted by highest version to lowest version.
     */
    private getTagsOrdered;
    /**
     * Creates a new draft release or updates an existing draft release for the given details.
     * An existing release is discovered by a matching tag.
     *
     * @param release The release details
     */
    updateDraftRelease(release: Release): Promise<void>;
    _uploadAsset(releaseDetails: ReleaseDetails, asset: Asset): Promise<void>;
    /**
     * Uploads an asset (or multiple assets) for a Github release, if the assets
     * already exists it will be removed and re-uploaded.
     */
    uploadReleaseAsset(releaseTag: string, assets: Asset | Asset[]): Promise<void>;
    getReleaseByTag(tag: string): Promise<ReleaseDetails>;
    promoteRelease(config: {
        version: string;
    }): Promise<string>;
    /**
     * Creates a new branch pointing to the latest commit of the given source branch.
     * @param branchName The name of the branch (not including refs/heads/)
     * @param sourceSha The SHA hash of the commit to branch off from
     */
    createBranch(branchName: string, sourceSha: string): Promise<void>;
    /**
     * Retrieves the details of the given branch.
     * @param branchName The name of the branch (not including refs/heads/)
     */
    getBranchDetails(branchName: string): Promise<Branch>;
    /**
     * Removes the given branch by deleting the corresponding ref.
     * @param branchName The branch name to remove (not including refs/heads/)
     */
    deleteBranch(branchName: string): Promise<void>;
    /**
     * Gets the content of the given file from the repository.
     * Assumes the loaded file is a utf-8 encoded text file.
     *
     * @param pathInRepo Path to the file from the repository root
     * @param branchOrTag Branch/tag name to load content from
     */
    getFileContent(pathInRepo: string, branchOrTag: string): Promise<{
        blobSha: string;
        content: string;
    }>;
    /**
     * Updates the content of a given file in the repository.
     * Assumes the given file content is utf-8 encoded text.
     *
     * @param message The commit message
     * @param baseSha The blob SHA of the file to update
     * @param pathInRepo Path to the file from the repository root
     * @param newContent New file content
     * @param branch Branch name to commit to
     */
    commitFileUpdate(message: string, baseSha: string, pathInRepo: string, newContent: string, branch: string): Promise<{
        blobSha: string;
        commitSha: string;
    }>;
    createPullRequest(title: string, description: string, fromBranch: string, toBaseBranch: string): Promise<{
        prNumber: number;
        url: string;
    }>;
    mergePullRequest(prNumber: number): Promise<void>;
    private _ignoreAlreadyExistsError;
    private _isAlreadyExistsError;
    private _getErrorMessage;
}
export {};
